@@ -91,7 +91,8 @@ def filter_coupons(coupon):
     filtered = {
         "id":int(coupon["id"]),
         "code":str(coupon["code"]),
-        "discount":float(coupon["discount"])
+        "discount":float(coupon["discount"]),
+        "discount_tax": float(coupon["discount_tax"])
     }
     return filtered
 
@@ -113,17 +114,16 @@ def get_last_date(totals, start_date):
        date = (pendulum.parse(date) if pendulum.parse(date) > pendulum.parse(i) else pendulum.parse(i)).to_date_string()
     return date    
 
-def filter_report(report, start_date, end_date):
+def filter_report(report, start_date):
     if "totals" in report and len(report["totals"]) > 0:
         totals = [filter_report_totals(report["totals"][date], date) for date in report["totals"]]
 
     try:
-        filtered = {**report, "totals": totals, "date_start": start_date, "date_end":end_date, "store_url": CONFIG["url"]}
+        filtered = {**report, "totals": totals, "date_start": start_date, "date_end":start_date, "store_url": CONFIG["url"]}
     except:
         filtered = {}
 
-    last_date = get_last_date(report["totals"], start_date)
-    return filtered, last_date    
+    return filtered    
 
 def filter_order(order):
     tzinfo = parser.parse(CONFIG["start_date"]).tzinfo
@@ -140,19 +140,24 @@ def filter_order(order):
     else:
         shipping_lines = None
 
+ 
     try:
-        filtered = {
-            "store_url": CONFIG["url"],
-            "order_id":int(order["id"]),
-            "order_key":str(order["order_key"]),
-            "status":str(order["status"]),
-            "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
-            "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
-            "discount_total":float(order["discount_total"]),
-            "shipping_total":float(order["shipping_total"]),
-            "total":float(order["total"]),
-            "line_items":line_items
-        }
+     filtered = {
+        "store_url": CONFIG["url"],
+        "order_id":int(order["id"]),
+        "order_key":str(order["order_key"]),
+        "total_tax": str(order["total_tax"]),
+        "discount_tax": str(order["discount_tax"]),
+        "discount_total": str(order["discount_total"]),
+        "status":str(order["status"]),
+        "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
+        "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
+        "discount_total":float(order["discount_total"]),
+        "shipping_total":float(order["shipping_total"]),
+        "coupon_lines": order["coupon_lines"],
+        "total":float(order["total"]),
+        "line_items":line_items
+    }
     except:
         filtered = {}    
     return filtered
@@ -214,16 +219,15 @@ def sync_reports(STATE, catalog):
     last_update = start
     with metrics.record_counter("reports") as counter:
         while True:
-            end_date = get_end_date(last_update)
-            endpoint = get_endpoint("reports", [last_update, end_date, CONFIG["consumer_key"], CONFIG["consumer_secret"]])
+            endpoint = get_endpoint("reports", [last_update, last_update, CONFIG["consumer_key"], CONFIG["consumer_secret"]])
             LOGGER.info("GET %s", endpoint)
             report_response = gen_request("reports", endpoint)
             counter.increment()
-            report, last_date = filter_report(report_response[0], last_update, end_date)
-            last_update = last_date
+            report = filter_report(report_response[0], last_update)
             singer.write_record("reports", report)
-            if pendulum.parse(end_date).to_date_string() == pendulum.yesterday().to_date_string():
+            if pendulum.parse(last_update).to_date_string() == pendulum.yesterday().to_date_string():
                 break
+            last_update = pendulum.parse(last_update).add(days=1).to_date_string()
     STATE = singer.write_bookmark(STATE, 'reports', 'date_end', last_update) 
     singer.write_state(STATE)
     LOGGER.info("Completed Reports Sync")
